==> neper-1.8.0.tgz: neper-1.8.0/src/neper_fm/GeoStuff/WriteGeo/WriteGeo2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"WriteGeo.h"

/* GeoInfo writes information into file. */
void
WriteGeoInfo (int argc, char **argv, char *Version, FILE * file)
{
  int i;

  fprintf (file, "/* This file was created by neper -FM Version %s. */\n",
	   Version);
  fprintf (file, "/* Command line: ");
  for (i = 0; i <= argc - 1; i++)
    fprintf (file, "%s ", argv[i]);
  fprintf (file, " */\n\n");

  return;
}


/* MeshingOptions writes the meshing options into file. */
void
WriteMeshingOptions (FILE * file)
{
  fprintf (file, "/* Options for the meshing: */\n");
  fprintf (file,
	   "General.Verbosity = 0;   /* as less messages as possible. */\n");
  fprintf (file,
	   "Mesh.MshFileVersion = 2; /* `msh' file format version. */\n");
  fprintf (file, "Mesh.Algorithm = 3;     /* meshing algorithm. */\n"); /* loading triangle */
  fprintf (file,
	   "Mesh.Algorithm3D = 4;    /* Netgen   meshing algorithm. */\n");
  fprintf (file, "\n");

  return;
}

void
WriteMeanCL (struct GEOPARA GeoPara, FILE * file)
{
  fprintf (file, "MeanCL=%.12f;\n\n", GeoPara.cl);

  return;
}

/* GeoVer writes vertices into file.
 */
void
WriteGeoVer (struct GEO Geo, struct GEOPARA GeoPara, FILE * file)
{
  int i;

  for (i = 1; i <= Geo.VerQty; i++)
    if (Geo.VerState[i] != -1)
      WriteThisVerWMCL (Geo, GeoPara, i, file, 0);

  return;
}

/* GeoEdge writes edges into file.
 */
void
WriteGeoEdge (struct GEO Geo, struct IN In, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.EdgeQty; i++)
    {
      if (Geo.EdgeState[i] == 0 && In.edgedis == 0)	/* std case */
	WriteThisEdge (Geo, i, file, 0);

      else if (Geo.EdgeState[i] == 0 && In.edgedis == 1	/* discretized edges */
	       && Geo.EdgeNodeQty[i] != 0)
	WriteThisDiscreteEdge (Geo, i, file);
      else if (Geo.EdgeState[i] == 0 && In.edgedis == 1
	       && Geo.EdgeNodeQty[i] == 0)
	{
	  fprintf (file, "\n/* Tessellation edge %d: */\n", i);
	  WriteThisEdge (Geo, i, file, 0);
	}
    }

  fprintf (file, "\n");

  return;
}

/* GeoFace writes faces into file.
 */
void
WriteGeoFace (struct GEO Geo, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.FaceQty; i++)
    if (Geo.FaceState[i] >= 0)
      {
	if (Geo.FaceDis[i] == 0)
	  WriteThisFace (Geo, i, file, 1);
	else
	  WriteThisDiscreteFace (Geo, i, file);
      }

  fprintf (file, "\n");

  return;
}

/* GeoPoly writes polyhedra into file.
 */
void
WriteGeoPoly (struct GEO Geo, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.PolyQty; i++)
    WriteThisPoly (Geo, i, file);

  return;
}

==> neper-1.8.1.tgz: neper-1.8.1/src/neper_fm/GeoStuff/WriteGeo/WriteGeo2.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include"WriteGeo.h"

/* GeoInfo writes information into file. */
void
WriteGeoInfo (int argc, char **argv, char *Version, FILE * file)
{
  int i;

  fprintf (file, "/*gmsh_geo keep this line unchanged.*/\n");
  fprintf (file, "/* This file was created by neper -FM Version %s. */\n",
	   Version);
  fprintf (file, "/* Command line: ");
  for (i = 0; i <= argc - 1; i++)
    fprintf (file, "%s ", argv[i]);
  fprintf (file, " */\n\n");

  return;
}


/* MeshingOptions writes the meshing options into file. */
void
WriteMeshingOptions (FILE * file)
{
  fprintf (file, "/* Options for the meshing: */\n");
  fprintf (file,
	   "General.Verbosity = 0;   /* as less messages as possible. */\n");
  fprintf (file,
	   "Mesh.MshFileVersion = 2; /* `msh' file format version. */\n");
  fprintf (file, "Mesh.Algorithm = 3;     /* meshing algorithm. */\n");	/* loading triangle */
  fprintf (file,
	   "Mesh.Algorithm3D = 4;    /* Netgen   meshing algorithm. */\n");
  fprintf (file, "\n");

  return;
}

void
WriteMeanCL (struct GEOPARA GeoPara, FILE * file)
{
  fprintf (file, "MeanCL=%.12f;\n\n", GeoPara.cl);

  return;
}

/* GeoVer writes vertices into file.
 */
void
WriteGeoVer (struct GEO Geo, struct GEOPARA GeoPara, FILE * file)
{
  int i;

  for (i = 1; i <= Geo.VerQty; i++)
    if (Geo.VerState[i] != -1)
      WriteThisVerWMCL (Geo, GeoPara, i, file, 0);

  return;
}

/* GeoEdge writes edges into file.
 */
void
WriteGeoEdge (struct GEO Geo, struct IN In, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.EdgeQty; i++)
  {
    if (Geo.EdgeState[i] == 0 && In.edgedis == 0)	/* std case */
      WriteThisEdge (Geo, i, file, 0);

    else if (Geo.EdgeState[i] == 0 && In.edgedis == 1	/* discretized edges */
	     && Geo.EdgeNodeQty[i] != 0)
      WriteThisDiscreteEdge (Geo, i, file);
    else if (Geo.EdgeState[i] == 0 && In.edgedis == 1
	     && Geo.EdgeNodeQty[i] == 0)
    {
      fprintf (file, "\n/* Tessellation edge %d: */\n", i);
      WriteThisEdge (Geo, i, file, 0);
    }
  }

  fprintf (file, "\n");

  return;
}

/* GeoFace writes faces into file.
 */
void
WriteGeoFace (struct GEO Geo, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.FaceQty; i++)
    if (Geo.FaceState[i] >= 0)
    {
      if (Geo.FaceDis[i] == 0)
	WriteThisFace (Geo, i, file, 1);
      else
	WriteThisDiscreteFace (Geo, i, file);
    }

  fprintf (file, "\n");

  return;
}

/* GeoPoly writes polyhedra into file.
 */
void
WriteGeoPoly (struct GEO Geo, FILE * file)
{
  int i;			/* mute variables */

  for (i = 1; i <= Geo.PolyQty; i++)
    WriteThisPoly (Geo, i, file);

  return;
}
